@@ -1,11 +1,11 @@
 package WebService::Hexonet;
 
-use 5.026_000;
+use 5.030;
 use strict;
 use warnings;
 use WebService::Hexonet::Connector;
 
-use version 0.9917; our $VERSION = version->declare('v2.9.2');
+use version 0.9917; our $VERSION = version->declare('v2.10.0');
 
 1;
 
