@@ -1,11 +1,11 @@
 package WebService::Hexonet::Connector::SocketConfig;
 
-use 5.026_000;
+use 5.030;
 use strict;
 use warnings;
 use utf8;
 
-use version 0.9917; our $VERSION = version->declare('v2.9.2');
+use version 0.9917; our $VERSION = version->declare('v2.10.0');
 
 
 sub new {
